@@ -23,6 +23,7 @@ ENV_VARS = [
     "MB_PASS",
     "MB_HOST",
     "MB_DATABASE",
+    "MB_SESSION_TOKEN",
 ]
 
 
@@ -82,12 +83,25 @@ class ListParam(click.Tuple):
 
 class OptionAcceptableFromConfig(click.Option):
     """This class override should be used on arguments that are marked `required=True` in order to give them
-    more resilence to raising an error when the option exists in the users config"""
+    more resilence to raising an error when the option exists in the users config.
+
+    This also overrides default values for boolean CLI flags (e.g. --use_metabase_http/--use_metabase_https) in options when
+    no CLI flag is passed, but a value is provided in the config file (e.g. metabase_use_http: True)."""
 
     def process_value(self, ctx: click.Context, value: Any) -> Any:
         if value is not None:
             value = self.type_cast_value(ctx, value)
 
+        assert self.name, "none config option"
+
+        if (
+            isinstance(self.type, click.types.BoolParamType)
+            and ctx.get_parameter_source(self.name)
+            == click.core.ParameterSource.DEFAULT
+            and self.name in CONFIG
+        ):
+            value = CONFIG[self.name]
+
         if self.required and self.value_is_missing(value):
             if self.name not in CONFIG:
                 raise click.core.MissingParameter(ctx=ctx, param=self)
@@ -233,10 +247,21 @@ def shared_opts(func: Callable) -> Callable:
         type=click.STRING,
         help="Metabase password",
     )
+    @click.option(
+        "--metabase_session_id",
+        metavar="TOKEN",
+        envvar="MB_SESSION_ID",
+        show_envvar=True,
+        default=None,
+        cls=OptionAcceptableFromConfig,
+        type=click.STRING,
+        help="Metabase session ID",
+    )
     @click.option(
         "--metabase_http/--metabase_https",
         "metabase_use_http",
         default=False,
+        cls=OptionAcceptableFromConfig,
         help="use HTTP or HTTPS to connect to Metabase. Default HTTPS",
     )
     @click.option(
@@ -248,6 +273,7 @@ def shared_opts(func: Callable) -> Callable:
     @click.option(
         "--metabase_sync/--metabase_sync_skip",
         "metabase_sync",
+        cls=OptionAcceptableFromConfig,
         default=True,
         help="Attempt to synchronize Metabase schema with local models. Default sync",
     )
@@ -268,7 +294,6 @@ def shared_opts(func: Callable) -> Callable:
 @click.version_option(__version__)
 def cli():
     """Model synchronization from dbt to Metabase."""
-    ...
 
 
 @click.command(cls=CommandController)
@@ -499,6 +524,11 @@ def config(ctx, inspect: bool = False, resolve: bool = False, env: bool = False)
     is_flag=True,
     help="Flag to append tags to table descriptions in Metabase (default False)",
 )
+@click.option(
+    "--metabase_exclude_sources",
+    is_flag=True,
+    help="Flag to skip exporting sources to Metabase (default False)",
+)
 @click.option(
     "-v",
     "--verbose",
@@ -521,10 +551,11 @@ def models(
     metabase_verify: Optional[str] = None,
     metabase_sync: bool = True,
     metabase_sync_timeout: Optional[int] = None,
+    metabase_exclude_sources: bool = False,
     dbt_include_tags: bool = True,
     dbt_docs_url: Optional[str] = None,
     verbose: bool = False,
-) -> None:
+):
     """Exports model documentation and semantic types from dbt to Metabase.
 
     Args:
@@ -543,6 +574,7 @@ def models(
         metabase_verify (Optional[str], optional): Path to custom certificate bundle to be used by Metabase client. Defaults to None.
         metabase_sync (bool, optional): Attempt to synchronize Metabase schema with local models. Defaults to True.
         metabase_sync_timeout (Optional[int], optional): Synchronization timeout (in secs). If set, we will fail hard on synchronization failure; if not set, we will proceed after attempting sync regardless of success. Only valid if sync is enabled. Defaults to None.
+        metabase_exclude_sources (bool, optional): Flag to skip exporting sources to Metabase. Defaults to False.
         dbt_include_tags (bool, optional): Flag to append tags to table descriptions in Metabase. Defaults to True.
         dbt_docs_url (Optional[str], optional): Pass in URL to dbt docs site. Appends dbt docs URL for each model to Metabase table description. Defaults to None.
         verbose (bool, optional): Flag which signals verbose output. Defaults to False.
@@ -579,6 +611,7 @@ def models(
         database=metabase_database,
         sync=metabase_sync,
         sync_timeout=metabase_sync_timeout,
+        exclude_sources=metabase_exclude_sources,
     )
 
     # Load client
