@@ -5,7 +5,13 @@ from typing import Sequence, Optional, MutableMapping
 
 # Allowed metabase.* fields
 # Should be covered by attributes in the MetabaseColumn class
-METABASE_META_FIELDS = ["special_type", "semantic_type", "visibility_type"]
+METABASE_META_FIELDS = [
+    "special_type",
+    "semantic_type",
+    "visibility_type",
+    "fk_target_table",
+    "fk_target_field",
+]
 
 
 class ModelType(str, Enum):
@@ -32,6 +38,7 @@ class MetabaseModel:
     name: str
     schema: str
     description: str = ""
+    display_name: Optional[str] = None
     points_of_interest: Optional[str] = None
     caveats: Optional[str] = None
 
@@ -40,6 +47,8 @@ class MetabaseModel:
     source: Optional[str] = None
     unique_id: Optional[str] = None
 
+    visibility_type: Optional[str] = None
+
     @property
     def ref(self) -> Optional[str]:
         if self.model_type == ModelType.nodes:
