@@ -145,6 +145,7 @@ class DbtFolderReader(DbtReader):
 
         # Resolved name is what the name will be in the database
         resolved_name = model.get("alias", model.get("identifier"))
+        display_name = meta.get("metabase.display_name")
         dbt_name = None
         if not resolved_name:
             resolved_name = model["name"]
@@ -153,6 +154,7 @@ class DbtFolderReader(DbtReader):
 
         return MetabaseModel(
             name=resolved_name,
+            display_name=display_name,
             schema=schema,
             description=description,
             points_of_interest=points_of_interest,
